<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="eo_001">
<context>
    <name>AuthenticationWidget</name>
    <message>
        <location filename="../src/GUI/authenticationwidget.cpp" line="15"/>
        <source>Username:</source>
        <translation>Uzantnomo:</translation>
    </message>
    <message>
        <location filename="../src/GUI/authenticationwidget.cpp" line="16"/>
        <source>Password:</source>
        <translation>Pasvorto:</translation>
    </message>
</context>
<context>
    <name>CadenceGraph</name>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="11"/>
        <source>rpm</source>
        <translation>rpm</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="12"/>
        <location filename="../src/GUI/cadencegraph.h" line="16"/>
        <source>Cadence</source>
        <translation>Kadenco</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="28"/>
        <source>Avg</source>
        <translation>Mez</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="30"/>
        <source>Max</source>
        <translation>Maks</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="33"/>
        <source>Average</source>
        <translation>Mezumo</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="35"/>
        <source>Maximum</source>
        <translation>Maksimumo</translation>
    </message>
</context>
<context>
    <name>CadenceGraphItem</name>
    <message>
        <location filename="../src/GUI/cadencegraphitem.cpp" line="18"/>
        <source>Maximum</source>
        <translation>Maksimumo</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraphitem.cpp" line="19"/>
        <location filename="../src/GUI/cadencegraphitem.cpp" line="21"/>
        <source>rpm</source>
        <translation>rpm</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraphitem.cpp" line="20"/>
        <source>Average</source>
        <translation>Mezumo</translation>
    </message>
</context>
<context>
    <name>Data</name>
    <message>
        <location filename="../src/data/data.cpp" line="234"/>
        <source>Supported files</source>
        <translation>Subtenataj dosieroj</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="235"/>
        <source>CSV files</source>
        <translation>CSV-dosieroj</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="236"/>
        <source>CUP files</source>
        <translation>CUP-dosieroj</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="237"/>
        <source>FIT files</source>
        <translation>FIT-dosieroj</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="238"/>
        <source>GeoJSON files</source>
        <translation>GeoJSON-dosieroj</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="239"/>
        <source>GPI files</source>
        <translation>GPI-dosieroj</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="240"/>
        <source>GPX files</source>
        <translation>GPX-dosieroj</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="241"/>
        <source>IGC files</source>
        <translation>IGC-dosieroj</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="242"/>
        <source>ITN files</source>
        <translation>ITN-dosieroj</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="243"/>
        <source>JPEG images</source>
        <translation>JPEG-bildoj</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="244"/>
        <source>KML files</source>
        <translation>KML-dosieroj</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="245"/>
        <source>LOC files</source>
        <translation>LOC-dosieroj</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="246"/>
        <source>NMEA files</source>
        <translation>NMEA-dosieroj</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="247"/>
        <source>ONmove files</source>
        <translation>ONmove-dosieroj</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="248"/>
        <source>OV2 files</source>
        <translation>OV2-dosieroj</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="249"/>
        <source>OziExplorer files</source>
        <translation>OziExplorer-dosieroj</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="250"/>
        <source>SLF files</source>
        <translation>SLF-dosieroj</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="251"/>
        <source>SML files</source>
        <translation>SML-dosieroj</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="252"/>
        <source>TCX files</source>
        <translation>TCX-dosieroj</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="253"/>
        <source>70mai GPS log files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="254"/>
        <source>VKX files</source>
        <translation>VKX dosieroj</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="255"/>
        <source>VTK files</source>
        <translation>VTK dosieroj</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="256"/>
        <source>TwoNav files</source>
        <translation>TwoNav-dosieroj</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="257"/>
        <source>GPSDump files</source>
        <translation>GPSDump-dosieroj</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="258"/>
        <source>All files</source>
        <translation>Ĉiuj dosieroj</translation>
    </message>
</context>
<context>
    <name>DirSelectWidget</name>
    <message>
        <location filename="../src/GUI/dirselectwidget.cpp" line="18"/>
        <source>System default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/dirselectwidget.cpp" line="40"/>
        <source>Select directory</source>
        <translation>Elekti dosierujon</translation>
    </message>
</context>
<context>
    <name>ElevationGraph</name>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="39"/>
        <location filename="../src/GUI/elevationgraph.h" line="16"/>
        <source>Elevation</source>
        <translation>Alteco</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="59"/>
        <source>Up</source>
        <extracomment>Use an Unicode arrow (U+2197) when there is no abbreviation or extremly short term for &quot;Up&quot; in your language</extracomment>
        <translation>⬈</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="63"/>
        <source>Down</source>
        <extracomment>Use an Unicode arrow (U+2198) when there is no abbreviation or extremly short term for &quot;Down&quot; in your language</extracomment>
        <translation>⬊</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="66"/>
        <source>Max</source>
        <extracomment>Use an abbreviation or a extremly short term</extracomment>
        <translation>Maks</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="69"/>
        <source>Min</source>
        <extracomment>Use an abbreviation or a extremly short term</extracomment>
        <translation>Min</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="72"/>
        <source>Ascent</source>
        <translation>Supreniro</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="74"/>
        <source>Descent</source>
        <translation>Malsupreniro</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="76"/>
        <source>Maximum</source>
        <translation>Maksimumo</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="78"/>
        <source>Minimum</source>
        <translation>Minimumo</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="181"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="184"/>
        <source>ft</source>
        <translation>ft</translation>
    </message>
</context>
<context>
    <name>ElevationGraphItem</name>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="35"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="35"/>
        <source>ft</source>
        <translation>ft</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="38"/>
        <source>Ascent</source>
        <translation>Supreniro</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="40"/>
        <source>Descent</source>
        <translation>Malsupreniro</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="42"/>
        <source>Maximum</source>
        <translation>Maksimumo</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="44"/>
        <source>Minimum</source>
        <translation>Minimumo</translation>
    </message>
</context>
<context>
    <name>FileSelectWidget</name>
    <message>
        <location filename="../src/GUI/fileselectwidget.cpp" line="46"/>
        <location filename="../src/GUI/fileselectwidget.cpp" line="51"/>
        <source>Select file</source>
        <translation>Elekti dosieron</translation>
    </message>
    <message>
        <location filename="../src/GUI/fileselectwidget.cpp" line="61"/>
        <source>No output file selected.</source>
        <translation>Neniu eligdosiero estas elektita.</translation>
    </message>
    <message>
        <location filename="../src/GUI/fileselectwidget.cpp" line="71"/>
        <source>%1 is a directory.</source>
        <translation>%1 estas dosierujo.</translation>
    </message>
    <message>
        <location filename="../src/GUI/fileselectwidget.cpp" line="75"/>
        <source>%1 is not writable.</source>
        <translation>%1 ne estas skribebla.</translation>
    </message>
</context>
<context>
    <name>Format</name>
    <message>
        <location filename="../src/GUI/format.cpp" line="54"/>
        <location filename="../src/GUI/format.cpp" line="64"/>
        <location filename="../src/GUI/format.cpp" line="93"/>
        <source>ft</source>
        <translation>ft</translation>
    </message>
    <message>
        <location filename="../src/GUI/format.cpp" line="57"/>
        <location filename="../src/GUI/format.cpp" line="60"/>
        <source>mi</source>
        <translation>mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/format.cpp" line="67"/>
        <location filename="../src/GUI/format.cpp" line="70"/>
        <source>nmi</source>
        <translation>nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/format.cpp" line="74"/>
        <location filename="../src/GUI/format.cpp" line="90"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="../src/GUI/format.cpp" line="77"/>
        <location filename="../src/GUI/format.cpp" line="80"/>
        <source>km</source>
        <translation>km</translation>
    </message>
</context>
<context>
    <name>GUI</name>
    <message>
        <location filename="../src/GUI/gui.cpp" line="202"/>
        <source>Quit</source>
        <translation>Ĉesi</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="210"/>
        <location filename="../src/GUI/gui.cpp" line="982"/>
        <location filename="../src/GUI/gui.cpp" line="1000"/>
        <source>Paths</source>
        <translation>Vojprefiksoj</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="214"/>
        <location filename="../src/GUI/gui.cpp" line="939"/>
        <location filename="../src/GUI/gui.cpp" line="940"/>
        <source>Keyboard controls</source>
        <translation>Klavarokomandoj</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="218"/>
        <location filename="../src/GUI/gui.cpp" line="906"/>
        <source>About GPXSee</source>
        <translation>Pri GPXSee</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="224"/>
        <source>Open...</source>
        <translation>Malfermi...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="231"/>
        <source>Open directory...</source>
        <translation>Malfermi dosierujon…</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="236"/>
        <source>Print...</source>
        <translation>Presi...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="242"/>
        <source>Export to PDF...</source>
        <translation>Eksporti kiel PDF...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="249"/>
        <source>Export to PNG...</source>
        <translation>Eksporti kiel PNG...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="256"/>
        <source>Close</source>
        <translation>Fermi</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="263"/>
        <source>Reload</source>
        <translation>Reŝargi</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="269"/>
        <source>Statistics...</source>
        <translation>Statistiko...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="279"/>
        <source>Clear list</source>
        <translation>Vakigi liston</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="291"/>
        <source>Load POI file...</source>
        <translation>Ŝargi POI-dosieron...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="295"/>
        <source>Select all files</source>
        <translation>Elekti ĉiujn dosierojn</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="300"/>
        <source>Unselect all files</source>
        <translation>Malelekti ĉiujn dosierojn</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="305"/>
        <source>Overlap POIs</source>
        <translation>Kovri POI-punktojn</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="310"/>
        <source>Show POI icons</source>
        <translation>Montri POI-bildsimbolojn</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="315"/>
        <source>Show POI labels</source>
        <translation>Montri POI-nomojn</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="321"/>
        <source>Show POIs</source>
        <translation>Montri POI-punktojn</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="333"/>
        <source>Show map</source>
        <translation>Montri mapon</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="342"/>
        <source>Load map...</source>
        <translation>Ŝargi mapon...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="347"/>
        <source>Load map directory...</source>
        <translation>Ŝargi dosierujon de mapoj…</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="350"/>
        <source>Clear tile cache</source>
        <translation>Vakigi kaŝmemoron</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="355"/>
        <location filename="../src/GUI/gui.cpp" line="958"/>
        <source>Next map</source>
        <translation>Sekva mapo</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="365"/>
        <source>Show cursor coordinates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="376"/>
        <source>Show position</source>
        <translation>Montri pozicion</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="382"/>
        <source>Follow position</source>
        <translation>Sekvi pozicion</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="387"/>
        <source>Show coordinates</source>
        <translation>Montri koordinatojn</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="393"/>
        <source>Show motion info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="400"/>
        <source>Show tracks</source>
        <translation>Montri vojojn</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="405"/>
        <source>Show routes</source>
        <translation>Montri itinerojn</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="410"/>
        <source>Show waypoints</source>
        <translation>Montri vojpunktojn</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="416"/>
        <source>Show areas</source>
        <translation>Montri areojn</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="421"/>
        <source>Waypoint icons</source>
        <translation>Vojpunktaj bildsimboloj</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="426"/>
        <source>Waypoint labels</source>
        <translation>Vojpunktaj etikedoj</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="431"/>
        <source>Route waypoints</source>
        <translation>Itinerpunktoj</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="436"/>
        <source>km/mi markers</source>
        <translation>km/mi markoj</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="441"/>
        <source>Legend</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="449"/>
        <source>Do not show</source>
        <translation>Ne montri</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="453"/>
        <source>Marker only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="457"/>
        <source>Date/time</source>
        <translation>Dato/tempo</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="461"/>
        <source>Coordinates</source>
        <translation>Koordinatoj</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="465"/>
        <source>Use styles</source>
        <translation>Uzi stilojn</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="483"/>
        <source>Show local DEM tiles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="486"/>
        <source>Show hillshading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="494"/>
        <source>Show graphs</source>
        <translation>Montri grafikaĵojn</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="502"/>
        <location filename="../src/GUI/gui.cpp" line="1449"/>
        <location filename="../src/GUI/gui.cpp" line="1509"/>
        <source>Distance</source>
        <translation>Distanco</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="509"/>
        <location filename="../src/GUI/gui.cpp" line="768"/>
        <location filename="../src/GUI/gui.cpp" line="1451"/>
        <location filename="../src/GUI/gui.cpp" line="1511"/>
        <source>Time</source>
        <translation>Tempo</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="515"/>
        <source>Show grid</source>
        <translation>Montri kradon</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="520"/>
        <source>Show slider info</source>
        <translation>Montri valoron de la ŝovilo</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="526"/>
        <source>Show tabs</source>
        <translation>Montri langetojn</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="532"/>
        <location filename="../src/GUI/gui.cpp" line="961"/>
        <source>Next graph tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="537"/>
        <location filename="../src/GUI/gui.cpp" line="963"/>
        <source>Previous graph tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="545"/>
        <source>Show toolbars</source>
        <translation>Montri ilobretojn</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="552"/>
        <source>Total time</source>
        <translation>Totala tempo</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="557"/>
        <location filename="../src/GUI/gui.cpp" line="1452"/>
        <location filename="../src/GUI/gui.cpp" line="1513"/>
        <source>Moving time</source>
        <translation>Movada tempo</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="564"/>
        <source>Metric</source>
        <translation>Metraj</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="569"/>
        <source>Imperial</source>
        <translation>Britimperiaj</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="575"/>
        <source>Nautical</source>
        <translation>Maraj</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="583"/>
        <source>Decimal degrees (DD)</source>
        <translation>Decimalaj gradoj (DG)</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="589"/>
        <source>Degrees and decimal minutes (DMM)</source>
        <translation>Gradoj kaj decimalaj minutoj (GDM)</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="596"/>
        <source>Degrees, minutes, seconds (DMS)</source>
        <translation>Gradoj, minutoj, sekundoj (GMS)</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="603"/>
        <source>Fullscreen mode</source>
        <translation>Plenekrana reĝimo</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="610"/>
        <source>Options...</source>
        <translation>Opcioj...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="617"/>
        <source>Next</source>
        <translation>Sekva</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="622"/>
        <source>Previous</source>
        <translation>Antaŭa</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="627"/>
        <source>Last</source>
        <translation>Lasta</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="632"/>
        <source>First</source>
        <translation>Unua</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="667"/>
        <source>&amp;File</source>
        <translation>&amp;Dosiero</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="670"/>
        <source>Open recent</source>
        <translation>Malfermi lastatempajn</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="695"/>
        <source>&amp;Map</source>
        <translation>&amp;Mapo</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="701"/>
        <source>Layers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="708"/>
        <source>&amp;Graph</source>
        <translation>&amp;Grafikaĵo</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="740"/>
        <source>&amp;POI</source>
        <translation>&amp;POI</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="760"/>
        <source>Position</source>
        <translation>Pozicio</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="989"/>
        <location filename="../src/GUI/gui.cpp" line="1007"/>
        <source>CRS directory:</source>
        <translation>CRS-dosierujo:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="995"/>
        <location filename="../src/GUI/gui.cpp" line="1013"/>
        <source>Symbols directory:</source>
        <translation>Dosierujo de simboloj:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1061"/>
        <source>Open directory</source>
        <translation>Malfermi dosierujon</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1130"/>
        <source>Error loading geo URI:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1136"/>
        <location filename="../src/GUI/gui.cpp" line="1176"/>
        <location filename="../src/GUI/gui.cpp" line="1864"/>
        <location filename="../src/GUI/gui.cpp" line="1969"/>
        <source>Don&apos;t show again</source>
        <translation>Ne montri denove</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="2031"/>
        <source>Clear &quot;%1&quot; tile cache?</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <location filename="../src/GUI/gui.cpp" line="2054"/>
        <source>Download %n DEM tiles?</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="720"/>
        <source>&amp;Data</source>
        <translation>Da&amp;teno</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="472"/>
        <source>Download data DEM</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="478"/>
        <source>Download map DEM</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="726"/>
        <source>Position info</source>
        <translation>Informo pri pozicio</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="752"/>
        <source>DEM</source>
        <translation>DEM</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="767"/>
        <source>&amp;Settings</source>
        <translation>&amp;Agordoj</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="772"/>
        <source>Units</source>
        <translation>Unuoj</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="777"/>
        <source>Coordinates format</source>
        <translation>Koordinata formato</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="790"/>
        <source>&amp;Help</source>
        <translation>&amp;Helpo</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="817"/>
        <source>File</source>
        <translation>Dosiero</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="827"/>
        <source>Show</source>
        <translation>Montri</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="835"/>
        <source>Navigation</source>
        <translation>Navigado</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="908"/>
        <location filename="../src/GUI/gui.cpp" line="916"/>
        <source>Version %1</source>
        <translation>Versio %1</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="911"/>
        <location filename="../src/GUI/gui.cpp" line="920"/>
        <source>GPXSee is distributed under the terms of the GNU General Public License version 3. For more info about GPXSee visit the project homepage at %1.</source>
        <translation>GPXSee estas distribuita laŭ la kondiĉoj de la GNU Ĝenerala Publika Permesilo, la versio 3. Por pliaj informoj pri GPXSee, vizitu la hejmpaĝo de projekto %1.</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="943"/>
        <source>Next file</source>
        <translation>Sekva dosiero</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="944"/>
        <source>Previous file</source>
        <translation>Antaŭa dosiero</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="946"/>
        <source>First file</source>
        <translation>Unua dosiero</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="948"/>
        <source>Last file</source>
        <translation>Lasta dosiero</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="949"/>
        <source>Append file</source>
        <translation>Postaldoni dosieron</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="950"/>
        <source>Next/Previous</source>
        <translation>Sekva/Antaŭa</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="952"/>
        <source>Toggle graph type</source>
        <translation>Baskuligi tipon de la grafikaĵo</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="954"/>
        <source>Toggle time type</source>
        <translation>Baskuligi tipon de la tempo</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="956"/>
        <source>Toggle position info</source>
        <translation>Baskuligi informon pr pozicio</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="360"/>
        <location filename="../src/GUI/gui.cpp" line="960"/>
        <source>Previous map</source>
        <translation>Antaŭa mapo</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="964"/>
        <source>Zoom in</source>
        <translation>Zomi</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="966"/>
        <source>Zoom out</source>
        <translation>Malzomi</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="968"/>
        <source>Digital zoom</source>
        <translation>Diĝita zomo</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="969"/>
        <source>Zoom</source>
        <translation>Zoom</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="970"/>
        <source>Copy coordinates</source>
        <translation>Kopii koordinatojn</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="971"/>
        <source>Left Click</source>
        <translation>Maldekstra klako</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="985"/>
        <location filename="../src/GUI/gui.cpp" line="1003"/>
        <source>Map directory:</source>
        <translation>Dosierujo kun mapoj:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="987"/>
        <location filename="../src/GUI/gui.cpp" line="1005"/>
        <source>POI directory:</source>
        <translation>Dosierujo kun POI:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="991"/>
        <location filename="../src/GUI/gui.cpp" line="1009"/>
        <source>DEM directory:</source>
        <translation>Dosierujo kun DEM-dateno:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="993"/>
        <location filename="../src/GUI/gui.cpp" line="1011"/>
        <source>Styles directory:</source>
        <translation>Dosierujo kun stildosieroj:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="997"/>
        <location filename="../src/GUI/gui.cpp" line="1015"/>
        <source>Tile cache directory:</source>
        <translation>Kaŝmemora dosierujo:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1026"/>
        <location filename="../src/GUI/gui.cpp" line="1029"/>
        <source>Open file</source>
        <translation>Malfermi dosieron</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1168"/>
        <source>Error loading data file:</source>
        <translation>Eraro dum la ŝargado de la datumdosiero:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1171"/>
        <location filename="../src/GUI/gui.cpp" line="1287"/>
        <source>Line: %1</source>
        <translation>Linio: %1</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1254"/>
        <location filename="../src/GUI/gui.cpp" line="1257"/>
        <source>Open POI file</source>
        <translation>Malfermi POI-dosieron</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1284"/>
        <source>Error loading POI file:</source>
        <translation>Eraro dum la ŝargado de la POI-dosiero:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1431"/>
        <location filename="../src/GUI/gui.cpp" line="1489"/>
        <source>Tracks</source>
        <translation>Vojoj</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1433"/>
        <location filename="../src/GUI/gui.cpp" line="1491"/>
        <source>Routes</source>
        <translation>Itineroj</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1435"/>
        <location filename="../src/GUI/gui.cpp" line="1493"/>
        <source>Waypoints</source>
        <translation>Vojpunktoj</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1437"/>
        <location filename="../src/GUI/gui.cpp" line="1495"/>
        <source>Areas</source>
        <translation>Areoj</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1441"/>
        <location filename="../src/GUI/gui.cpp" line="1443"/>
        <location filename="../src/GUI/gui.cpp" line="1500"/>
        <location filename="../src/GUI/gui.cpp" line="1502"/>
        <source>Date</source>
        <translation>Dato</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1464"/>
        <location filename="../src/GUI/gui.cpp" line="1467"/>
        <location filename="../src/GUI/gui.cpp" line="1468"/>
        <source>Statistics</source>
        <translation>Statistiko</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1485"/>
        <source>Name</source>
        <translation>Nomo</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1803"/>
        <location filename="../src/GUI/gui.cpp" line="1806"/>
        <source>Open map file</source>
        <translation>Malfermi mapdosieron</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1858"/>
        <location filename="../src/GUI/gui.cpp" line="1920"/>
        <location filename="../src/GUI/gui.cpp" line="1939"/>
        <location filename="../src/GUI/gui.cpp" line="1963"/>
        <source>Error loading map:</source>
        <translation>Eraro dum la ŝargado de la mapo:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="2003"/>
        <source>Select map directory</source>
        <translation>Elekti dosierujon kun mapoj</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="2051"/>
        <source>DEM tiles download limit exceeded. If you really need data for such a huge area, download the files manually.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="2067"/>
        <source>Could not download all required DEM files.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="2084"/>
        <source>No local DEM tiles found.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="2095"/>
        <source>No files loaded</source>
        <translation>Neniuj dosieroj estas ŝargitaj</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/GUI/gui.cpp" line="2099"/>
        <source>%n files</source>
        <translation>
            <numerusform>%n dosiero</numerusform>
            <numerusform>%n dosieroj</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>GearRatioGraph</name>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="12"/>
        <location filename="../src/GUI/gearratiograph.h" line="17"/>
        <source>Gear ratio</source>
        <translation>Rapidumproporcio</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="28"/>
        <source>Top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="30"/>
        <source>Min</source>
        <translation>Min</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="32"/>
        <source>Max</source>
        <translation>Maks</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="35"/>
        <source>Most used</source>
        <translation>Plej uzita</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="37"/>
        <source>Minimum</source>
        <translation>Minimumo</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="39"/>
        <source>Maximum</source>
        <translation>Maksimumo</translation>
    </message>
</context>
<context>
    <name>GearRatioGraphItem</name>
    <message>
        <location filename="../src/GUI/gearratiographitem.cpp" line="37"/>
        <source>Minimum</source>
        <translation>Minimumo</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiographitem.cpp" line="38"/>
        <source>Maximum</source>
        <translation>Maksimumo</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiographitem.cpp" line="39"/>
        <source>Most used</source>
        <translation>Plej uzita</translation>
    </message>
</context>
<context>
    <name>GraphView</name>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="67"/>
        <source>Data not available</source>
        <translation>Dateno ne estas disponebla</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="86"/>
        <location filename="../src/GUI/graphview.cpp" line="191"/>
        <source>Distance</source>
        <translation>Distanco</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="123"/>
        <location filename="../src/GUI/graphview.cpp" line="131"/>
        <source>ft</source>
        <translation>ft</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="126"/>
        <source>mi</source>
        <translation>mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="134"/>
        <source>nmi</source>
        <translation>nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="139"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="142"/>
        <source>km</source>
        <translation>km</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="148"/>
        <source>s</source>
        <translation>s</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="151"/>
        <source>min</source>
        <translation>min</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="154"/>
        <source>h</source>
        <translation>h</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="193"/>
        <source>Time</source>
        <translation>Tempo</translation>
    </message>
</context>
<context>
    <name>HeartRateGraph</name>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="11"/>
        <source>bpm</source>
        <translation>bpm</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="12"/>
        <location filename="../src/GUI/heartrategraph.h" line="16"/>
        <source>Heart rate</source>
        <translation>Pulso</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="28"/>
        <source>Avg</source>
        <translation>Mez</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="30"/>
        <source>Max</source>
        <translation>Maks</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="33"/>
        <source>Average</source>
        <translation>Mezumo</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="35"/>
        <source>Maximum</source>
        <translation>Maksimumo</translation>
    </message>
</context>
<context>
    <name>HeartRateGraphItem</name>
    <message>
        <location filename="../src/GUI/heartrategraphitem.cpp" line="19"/>
        <source>Maximum</source>
        <translation>Maksimumo</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraphitem.cpp" line="20"/>
        <location filename="../src/GUI/heartrategraphitem.cpp" line="22"/>
        <source>bpm</source>
        <translation>bpm</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraphitem.cpp" line="21"/>
        <source>Average</source>
        <translation>Mezumo</translation>
    </message>
</context>
<context>
    <name>IMGMap</name>
    <message>
        <location filename="../src/map/imgmap.cpp" line="305"/>
        <source>All</source>
        <translation type="unfinished">Ĉiuj</translation>
    </message>
    <message>
        <location filename="../src/map/imgmap.cpp" line="305"/>
        <source>Vector only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/map/imgmap.cpp" line="305"/>
        <source>Raster only</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MapItem</name>
    <message>
        <location filename="../src/GUI/mapitem.cpp" line="80"/>
        <source>Name</source>
        <translation>Nomo</translation>
    </message>
    <message>
        <location filename="../src/GUI/mapitem.cpp" line="82"/>
        <source>File</source>
        <translation>Dosiero</translation>
    </message>
</context>
<context>
    <name>MapList</name>
    <message>
        <location filename="../src/map/maplist.cpp" line="158"/>
        <source>Supported files</source>
        <translation>Subtenataj dosieroj</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="162"/>
        <source>AlpineQuest maps</source>
        <translation>AlpineQuest-mapoj</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="164"/>
        <source>Garmin IMG maps</source>
        <translation>Garmin IMG -mapoj</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="166"/>
        <source>Garmin JNX maps</source>
        <translation>Garmin JNX -mapoj</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="167"/>
        <source>BSB nautical charts</source>
        <translation>BSB -maraj mapoj</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="163"/>
        <source>GEMF maps</source>
        <translation>GEMF-mapoj</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="160"/>
        <source>Electronic Navigational Charts</source>
        <translation>ENC-mapoj</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="168"/>
        <source>KMZ maps</source>
        <translation>KMZ-mapoj</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="169"/>
        <source>Mapsforge maps</source>
        <translation>Mapsforge-mapoj</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="170"/>
        <source>OziExplorer maps</source>
        <translation>OziExplorer-mapoj</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="171"/>
        <source>MBTiles maps</source>
        <translation>MBTiles-mapoj</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="172"/>
        <source>Orux maps</source>
        <translation>Orux-mapoj</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="173"/>
        <source>QuickChart maps</source>
        <translation>QuickChart-mapoj</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="175"/>
        <source>Osmdroid SQLite maps</source>
        <translation>Osmdroid SQLite -mapoj</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="178"/>
        <source>TrekBuddy maps/atlases</source>
        <translation>TrekBuddy-mapoj/maparoj</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="180"/>
        <source>GeoTIFF images</source>
        <translation>GeoTIFF-bildoj</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="184"/>
        <source>All files</source>
        <translation>Ĉiuj dosieroj</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="174"/>
        <source>TwoNav maps</source>
        <translation>TwoNav-mapoj</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="176"/>
        <source>Locus/OsmAnd/RMaps SQLite maps</source>
        <translation>Locus/OsmAnd/RMaps SQLite -mapoj</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="181"/>
        <source>World-file georeferenced images</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="183"/>
        <source>Online map sources</source>
        <translation>Fontoj de Online-mapoj</translation>
    </message>
</context>
<context>
    <name>MotionInfoItem</name>
    <message>
        <location filename="../src/GUI/motioninfoitem.cpp" line="87"/>
        <source>kn</source>
        <translation>kn</translation>
    </message>
    <message>
        <location filename="../src/GUI/motioninfoitem.cpp" line="90"/>
        <source>mi/h</source>
        <translation>mi/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/motioninfoitem.cpp" line="93"/>
        <source>km/h</source>
        <translation>km/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/motioninfoitem.cpp" line="100"/>
        <source>ft/min</source>
        <translation>ft/min</translation>
    </message>
    <message>
        <location filename="../src/GUI/motioninfoitem.cpp" line="103"/>
        <source>m/min</source>
        <translation>m/min</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="86"/>
        <source>Standard</source>
        <translation>Norma</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="91"/>
        <source>Non-HiDPI maps are loaded as HiDPI maps. The map is sharp but map objects are small/hard to read.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="93"/>
        <source>Non-HiDPI maps are loaded such as they are. Map objects have the expected size but the map is blurry.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="103"/>
        <source>Input</source>
        <translation>Enigo</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="105"/>
        <source>Output</source>
        <translation>Eligo</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="112"/>
        <source>Input:</source>
        <translation>Enigo:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="115"/>
        <source>Output:</source>
        <translation>Eligo:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="136"/>
        <source>Projection</source>
        <translation>Projekcio</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="137"/>
        <source>HiDPI display mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="177"/>
        <source>Track width:</source>
        <translation>Larĝo de vojo:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="178"/>
        <source>Track style:</source>
        <translation>Stilo de vojo:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="194"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="199"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="204"/>
        <source>Width:</source>
        <translation>Larĝo:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="195"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="200"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="205"/>
        <source>Style:</source>
        <translation>Stilo:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="196"/>
        <source>Tracks</source>
        <translation>Vojoj</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="180"/>
        <source>Route width:</source>
        <translation>Larĝo de itinero:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="181"/>
        <source>Route style:</source>
        <translation>Stilo de itinero:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="201"/>
        <source>Routes</source>
        <translation>Itineroj</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="183"/>
        <source>Area border width:</source>
        <translation>Larĝo de area limo:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="184"/>
        <source>Area border style:</source>
        <translation>Stilo de area limo:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="185"/>
        <source>Area fill opacity:</source>
        <translation>Opakeco de area plenigo:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="207"/>
        <source>Areas</source>
        <translation>Areoj</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="187"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="210"/>
        <source>Base color:</source>
        <translation>Baza koloro:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="188"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="211"/>
        <source>Palette shift:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="171"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="275"/>
        <source>Use anti-aliasing</source>
        <translation>Uzi glatigon</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="243"/>
        <source>Waypoint color:</source>
        <translation>Vojpunkta koloro:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="244"/>
        <source>Waypoint size:</source>
        <translation>Vojpunkta grandeco:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="251"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="256"/>
        <source>Color:</source>
        <translation>Koloro:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="252"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="257"/>
        <source>Size:</source>
        <translation>Grandeco:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="253"/>
        <source>Waypoints</source>
        <translation>Vojpunktoj</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="246"/>
        <source>POI color:</source>
        <translation>Koloro de POI:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="247"/>
        <source>POI size:</source>
        <translation>Grandeco de POI:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="258"/>
        <source>POIs</source>
        <translation>POI-punktoj</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="281"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="287"/>
        <source>Line width:</source>
        <translation>Linia larĝo:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="282"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="288"/>
        <source>Slider color:</source>
        <translation>Koloro de ŝovilo:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="313"/>
        <source>Background color:</source>
        <translation>Fona koloro:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="326"/>
        <source>Paths</source>
        <translation>Vojoj</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="327"/>
        <source>Points</source>
        <translation>Punktoj</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="328"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="764"/>
        <source>Graphs</source>
        <translation>Grafikaĵoj</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="329"/>
        <source>Map</source>
        <translation>Mapo</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="336"/>
        <source>Moving average window size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="361"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="371"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="495"/>
        <source>Elevation:</source>
        <translation>Alteco:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="362"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="372"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="494"/>
        <source>Speed:</source>
        <translation>Rapideco:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="363"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="373"/>
        <source>Heart rate:</source>
        <translation>Pulso:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="364"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="374"/>
        <source>Cadence:</source>
        <translation>Kadenco:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="365"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="375"/>
        <source>Power:</source>
        <translation>Povumo:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="360"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="378"/>
        <source>Smoothing</source>
        <translation>Glatigo</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="354"/>
        <source>Eliminate GPS outliers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="391"/>
        <source>Automatic</source>
        <translation>Aŭtomata</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="392"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="446"/>
        <source>Custom</source>
        <translation>Propra</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="405"/>
        <source>mi/h</source>
        <translation>mi/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="408"/>
        <source>kn</source>
        <translation>kn</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="411"/>
        <source>km/h</source>
        <translation>km/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="415"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="791"/>
        <source>s</source>
        <translation>s</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="538"/>
        <source>Minimal speed:</source>
        <translation>Minimuma rapideco:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="539"/>
        <source>Minimal duration:</source>
        <translation>Minimuma daŭro:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="426"/>
        <source>Computed from distance/time</source>
        <translation>Komputita de la distanco/tempo</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="427"/>
        <source>Recorded by device</source>
        <translation>Registrita per aparato</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="432"/>
        <source>Show secondary speed</source>
        <translation>Montri ambaŭ samtempe</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="435"/>
        <source>GPS data</source>
        <translation>GPS-datumoj</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="436"/>
        <source>DEM data</source>
        <translation>DEM-datumoj</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="441"/>
        <source>Show secondary elevation</source>
        <translation>Montri ambaŭ samtempe</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="444"/>
        <source>UTC</source>
        <translation>UTC</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="445"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="842"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="893"/>
        <source>System</source>
        <translation>Sistemo</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="465"/>
        <source>Use segments</source>
        <translation>Uzi segmentojn</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="496"/>
        <source>Time zone:</source>
        <translation>Horzono:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="510"/>
        <source>Speed</source>
        <translation>Rapideco</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="515"/>
        <source>Elevation</source>
        <translation>Alteco</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="521"/>
        <source>Time zone</source>
        <translation>Horzono</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="551"/>
        <source>Filtering</source>
        <translation>Filtrado</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="550"/>
        <source>Sources</source>
        <translation>Datumfontoj</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="78"/>
        <source>Select the proper coordinate reference system (CRS) of maps without a CRS definition (JNX, KMZ and World file maps).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="81"/>
        <source>Select the desired projection of vector maps (IMG, Mapsforge and ENC maps). The projection must be valid for the whole map area.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="147"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="154"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="160"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="228"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="235"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="273"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="639"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="309"/>
        <source>Info background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="315"/>
        <source>Crosshair color:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="316"/>
        <source>Info color:</source>
        <translation>Teksta koloro:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="552"/>
        <source>Pause detection</source>
        <translation>Malkovro de paŭzoj</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="564"/>
        <source>mi</source>
        <translation>mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="567"/>
        <source>nmi</source>
        <translation>nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="570"/>
        <source>km</source>
        <translation>km</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="574"/>
        <source>Radius:</source>
        <translation>Radiuso:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="580"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="884"/>
        <source>POI</source>
        <translation>POI</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="597"/>
        <source>Use HTTP authentication</source>
        <translation>Uzi HTTP-aŭtentigon</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="603"/>
        <source>Use $lat and $lon for NYY/SYY and EXXX/WXXX in the URL.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="608"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="621"/>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="206"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="314"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="655"/>
        <source>Opacity:</source>
        <translation>Opakeco:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="657"/>
        <source>Blur radius:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="659"/>
        <source>Azimuth:</source>
        <translation>Azimuto:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="660"/>
        <source>Altitude:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="661"/>
        <source>Z Factor:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="666"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="696"/>
        <source>Source</source>
        <translation>Fonto</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="667"/>
        <source>Hillshading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="685"/>
        <source>Plugin:</source>
        <translation>Kromprogramo:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="703"/>
        <source>WYSIWYG</source>
        <translation>WYSIWYG</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="85"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="704"/>
        <source>High-Resolution</source>
        <translation>Granda distingivo</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="388"/>
        <source>Detect pauses</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="537"/>
        <source>Detection:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="656"/>
        <source>Lightening:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="709"/>
        <source>The printed area is approximately the display area. The map zoom level does not change.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="711"/>
        <source>The zoom level will be changed so that the whole content (tracks/waypoints) fits to the printed area and the map resolution is as close as possible to the print resolution.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="727"/>
        <source>Name</source>
        <translation>Nomo</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="729"/>
        <source>Date</source>
        <translation>Dato</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="731"/>
        <source>Distance</source>
        <translation>Distanco</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="733"/>
        <source>Time</source>
        <translation>Tempo</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="735"/>
        <source>Moving time</source>
        <translation>Movada tempo</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="737"/>
        <source>Item count (&gt;1)</source>
        <translation>Nombro de objektoj (&gt;1)</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="752"/>
        <source>Separate graph page</source>
        <translation>Grafikaĵo sur aparta paĝo</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="762"/>
        <source>Print mode</source>
        <translation>Presa reĝimo</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="763"/>
        <source>Header</source>
        <translation>Paĝokapo</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="771"/>
        <source>Use OpenGL</source>
        <translation>Uzi OpenGL</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="773"/>
        <source>Enable HTTP/2</source>
        <translation>Ŝalti HTTP/2</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="779"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="785"/>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="797"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="805"/>
        <source>Image cache size:</source>
        <translation>Bildkaŝmemora grando:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="799"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="807"/>
        <source>Connection timeout:</source>
        <translation>Tempolimo de konekto:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="798"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="806"/>
        <source>DEM cache size:</source>
        <translation>DEM-kaŝmemora grandeco:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="826"/>
        <source>Select the initial paths of the file open dialogues. Leave the field empty for the system default.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="830"/>
        <source>Data:</source>
        <translation>Dateno:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="831"/>
        <source>Maps:</source>
        <translation>Mapoj:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="832"/>
        <source>POI:</source>
        <translation>POI:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="843"/>
        <source>Initial paths</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="879"/>
        <source>Appearance</source>
        <translation>Aspekto</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="881"/>
        <source>Maps</source>
        <translation>Mapoj</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="883"/>
        <source>Data</source>
        <translation>Dateno</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="886"/>
        <source>DEM</source>
        <translation>DEM</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="889"/>
        <source>Position</source>
        <translation>Pozicio</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="891"/>
        <source>Print &amp; Export</source>
        <translation>Preso kaj eksporto</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="926"/>
        <source>Options</source>
        <translation>Opcioj</translation>
    </message>
</context>
<context>
    <name>PDFExportDialog</name>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="28"/>
        <source>PDF files</source>
        <translation>PDF-dosieroj</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="28"/>
        <source>All files</source>
        <translation>Ĉiuj dosieroj</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="56"/>
        <source>Portrait</source>
        <translation>Vertikala</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="57"/>
        <source>Landscape</source>
        <translation>Horizontala</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="67"/>
        <source>cm</source>
        <translation>cm</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="67"/>
        <source>in</source>
        <translation>in</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="73"/>
        <source>Page Setup</source>
        <translation>Paĝo-agordo</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="76"/>
        <source>Page size:</source>
        <translation>Grandeco de paĝo:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="77"/>
        <source>Resolution:</source>
        <translation>Distingivo:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="78"/>
        <source>Orientation:</source>
        <translation>Orientiĝo:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="79"/>
        <source>Margins:</source>
        <translation>Marĝenoj:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="85"/>
        <source>File:</source>
        <translation>Dosiero:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="92"/>
        <source>Output file</source>
        <translation>Eligdosiero</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="99"/>
        <source>Export</source>
        <translation>Eksporti</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="119"/>
        <source>Export to PDF</source>
        <translation>Eksporti kiel PDF</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="127"/>
        <source>Error</source>
        <translation>Eraro</translation>
    </message>
</context>
<context>
    <name>PNGExportDialog</name>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="25"/>
        <source>PNG files</source>
        <translation>PNG-dosieroj</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="25"/>
        <source>All files</source>
        <translation>Ĉiuj dosieroj</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="34"/>
        <location filename="../src/GUI/pngexportdialog.cpp" line="39"/>
        <location filename="../src/GUI/pngexportdialog.cpp" line="43"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="45"/>
        <source>Use anti-aliasing</source>
        <translation>Uzi glatigon</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="49"/>
        <source>Image Setup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="52"/>
        <source>Image width:</source>
        <translation>Bildlarĝo:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="53"/>
        <source>Image height:</source>
        <translation>Bildalteco:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="54"/>
        <source>Margins:</source>
        <translation>Marĝenoj:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="61"/>
        <source>File:</source>
        <translation>Dosiero:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="68"/>
        <source>Output file</source>
        <translation>Eligdosiero</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="75"/>
        <source>Export</source>
        <translation>Eksporti</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="95"/>
        <source>Export to PNG</source>
        <translation>Eksporti kiel PNG</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="103"/>
        <source>Error</source>
        <translation>Eraro</translation>
    </message>
</context>
<context>
    <name>PolygonItem</name>
    <message>
        <location filename="../src/GUI/areaitem.cpp" line="18"/>
        <source>Name</source>
        <translation>Nomo</translation>
    </message>
    <message>
        <location filename="../src/GUI/areaitem.cpp" line="20"/>
        <source>Description</source>
        <translation>Priskribo</translation>
    </message>
</context>
<context>
    <name>PowerGraph</name>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="11"/>
        <source>W</source>
        <translation>W</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="12"/>
        <location filename="../src/GUI/powergraph.h" line="16"/>
        <source>Power</source>
        <translation>Povumo</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="28"/>
        <source>Avg</source>
        <translation>Mez</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="30"/>
        <source>Max</source>
        <translation>Maks</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="33"/>
        <source>Average</source>
        <translation>Mezumo</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="35"/>
        <source>Maximum</source>
        <translation>Maksimumo</translation>
    </message>
</context>
<context>
    <name>PowerGraphItem</name>
    <message>
        <location filename="../src/GUI/powergraphitem.cpp" line="18"/>
        <source>Maximum</source>
        <translation>Maksimumo</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraphitem.cpp" line="19"/>
        <location filename="../src/GUI/powergraphitem.cpp" line="21"/>
        <source>W</source>
        <translation>W</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraphitem.cpp" line="20"/>
        <source>Average</source>
        <translation>Mezumo</translation>
    </message>
</context>
<context>
    <name>RouteItem</name>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="16"/>
        <source>Name</source>
        <translation>Nomo</translation>
    </message>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="18"/>
        <source>Description</source>
        <translation>Priskribo</translation>
    </message>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="20"/>
        <source>Comment</source>
        <translation>Komento</translation>
    </message>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="21"/>
        <source>Distance</source>
        <translation>Distanco</translation>
    </message>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="32"/>
        <source>Links</source>
        <translation>Ligiloj</translation>
    </message>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="38"/>
        <source>File</source>
        <translation>Dosiero</translation>
    </message>
</context>
<context>
    <name>ScaleItem</name>
    <message>
        <location filename="../src/GUI/scaleitem.cpp" line="108"/>
        <source>mi</source>
        <translation>mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/scaleitem.cpp" line="109"/>
        <location filename="../src/GUI/scaleitem.cpp" line="112"/>
        <source>ft</source>
        <translation>ft</translation>
    </message>
    <message>
        <location filename="../src/GUI/scaleitem.cpp" line="111"/>
        <source>nmi</source>
        <translation>nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/scaleitem.cpp" line="114"/>
        <source>km</source>
        <translation>km</translation>
    </message>
    <message>
        <location filename="../src/GUI/scaleitem.cpp" line="115"/>
        <source>m</source>
        <translation>m</translation>
    </message>
</context>
<context>
    <name>SpeedGraph</name>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="15"/>
        <location filename="../src/GUI/speedgraph.h" line="18"/>
        <source>Speed</source>
        <translation>Rapideco</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="30"/>
        <source>min/km</source>
        <translation>min/km</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="31"/>
        <source>min/mi</source>
        <translation>min/mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="31"/>
        <source>min/nmi</source>
        <translation>min/nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="34"/>
        <source>Avg</source>
        <translation>Mez</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="36"/>
        <source>Max</source>
        <translation>Maks</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="39"/>
        <source>Average</source>
        <translation>Mezumo</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="41"/>
        <source>Maximum</source>
        <translation>Maksimumo</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="44"/>
        <source>Pace</source>
        <translation>Ritmo</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="146"/>
        <source>kn</source>
        <translation>kn</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="149"/>
        <source>mi/h</source>
        <translation>mi/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="152"/>
        <source>km/h</source>
        <translation>km/h</translation>
    </message>
</context>
<context>
    <name>SpeedGraphItem</name>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="25"/>
        <source>mi/h</source>
        <translation>mi/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="26"/>
        <source>kn</source>
        <translation>kn</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="26"/>
        <source>km/h</source>
        <translation>km/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="29"/>
        <source>min/km</source>
        <translation>min/km</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="30"/>
        <source>min/mi</source>
        <translation>min/mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="30"/>
        <source>min/nmi</source>
        <translation>min/nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="33"/>
        <source>Maximum</source>
        <translation>Maksimumo</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="35"/>
        <source>Average</source>
        <translation>Mezumo</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="37"/>
        <source>Pace</source>
        <translation>Ritmo</translation>
    </message>
</context>
<context>
    <name>TemperatureGraph</name>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="12"/>
        <location filename="../src/GUI/temperaturegraph.h" line="16"/>
        <source>Temperature</source>
        <translation>Temperaturo</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="28"/>
        <source>Avg</source>
        <translation>Mez</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="30"/>
        <source>Min</source>
        <translation>Min</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="32"/>
        <source>Max</source>
        <translation>Maks</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="35"/>
        <source>Average</source>
        <translation>Mezumo</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="37"/>
        <source>Minimum</source>
        <translation>Minimumo</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="39"/>
        <source>Maximum</source>
        <translation>Maksimumo</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="112"/>
        <source>C</source>
        <translation>C</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="116"/>
        <source>F</source>
        <translation>F</translation>
    </message>
</context>
<context>
    <name>TemperatureGraphItem</name>
    <message>
        <location filename="../src/GUI/temperaturegraphitem.cpp" line="23"/>
        <source>C</source>
        <translation>C</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraphitem.cpp" line="23"/>
        <source>F</source>
        <translation>F</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraphitem.cpp" line="26"/>
        <source>Average</source>
        <translation>Mezumo</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraphitem.cpp" line="28"/>
        <source>Maximum</source>
        <translation>Maksimumo</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraphitem.cpp" line="30"/>
        <source>Minimum</source>
        <translation>Minimumo</translation>
    </message>
</context>
<context>
    <name>TrackItem</name>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="15"/>
        <source>Name</source>
        <translation>Nomo</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="17"/>
        <source>Description</source>
        <translation>Priskribo</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="19"/>
        <source>Comment</source>
        <translation>Komento</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="20"/>
        <source>Distance</source>
        <translation>Distanco</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="23"/>
        <source>Total time</source>
        <translation>Totala tempo</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="25"/>
        <source>Moving time</source>
        <translation>Movada tempo</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="28"/>
        <source>Date</source>
        <translation>Dato</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="40"/>
        <source>Links</source>
        <translation>Ligiloj</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="46"/>
        <source>File</source>
        <translation>Dosiero</translation>
    </message>
</context>
<context>
    <name>WaypointItem</name>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="26"/>
        <source>Name</source>
        <translation>Nomo</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="27"/>
        <source>Coordinates</source>
        <translation>Koordinatoj</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="34"/>
        <source>Elevation</source>
        <translation>Alteco</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="38"/>
        <source>Date</source>
        <translation>Dato</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="43"/>
        <source>Description</source>
        <translation>Priskribo</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="47"/>
        <source>Comment</source>
        <translation>Komento</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="50"/>
        <source>Symbol</source>
        <translation>Simbolo</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="55"/>
        <source>Address</source>
        <translation>Adreso</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="58"/>
        <source>Phone</source>
        <translation>Telefono</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="68"/>
        <source>Links</source>
        <translation>Ligiloj</translation>
    </message>
</context>
</TS>
